@@ -1,19 +1,19 @@
-from typing import Callable, List, Optional, cast
+from typing import List, Optional, cast
 
 from hpcrocket.core.environmentpreparation import (CopyInstruction,
                                                    EnvironmentPreparation)
 from hpcrocket.core.errors import get_error_message
 from hpcrocket.core.filesystem import FilesystemFactory
-from hpcrocket.core.launchoptions import LaunchOptions
 from hpcrocket.core.slurmbatchjob import SlurmBatchJob, SlurmJobStatus
 from hpcrocket.core.slurmcontroller import SlurmController
+from hpcrocket.typesafety import get_or_raise
 from hpcrocket.ui import UI
-from hpcrocket.watcher.jobwatcher import JobWatcher, SlurmJobStatusCallback
-
+from hpcrocket.watcher.jobwatcher import (JobWatcher, NotWatchingError,
+                                          SlurmJobStatusCallback)
 
 try:
     from typing import Protocol
-except ImportError:
+except ImportError:  # pragma: no cover
     from typing_extensions import Protocol  # type: ignore
 
 
@@ -22,12 +22,15 @@ class NoJobLaunchedError(Exception):
 
 
 class LaunchStage:
+    """
+    Launches a batch job.
+    Implements the BatchJobProvider protocol to work with WatchStage.
+    """
 
     def __init__(self, controller: SlurmController, batch_script: str) -> None:
         self._controller = controller
         self._batch_script = batch_script
-        self._batch_job: SlurmBatchJob = None  # type: ignore[assignment]
-        self._watch_stage: WatchStage = None  # type: ignore[assignment]
+        self._batch_job: Optional[SlurmBatchJob] = None
 
     def __call__(self, ui: UI) -> bool:
         self._batch_job = self._controller.submit(self._batch_script)
@@ -36,21 +39,23 @@ class LaunchStage:
         return True
 
     def cancel(self, ui: UI) -> None:
-        self._raise_if_not_launched()
+        batch_job = get_or_raise(self._batch_job, self._no_job_launched())
 
-        ui.info(f"Canceling job {self._batch_job.jobid}")
-        self._batch_job.cancel()
-        ui.success(f"Canceled job {self._batch_job.jobid}")
+        ui.info(f"Canceling job {batch_job.jobid}")
+        batch_job.cancel()
+        ui.success(f"Canceled job {batch_job.jobid}")
 
-    def _raise_if_not_launched(self) -> None:
-        if not self._batch_job:
-            raise NoJobLaunchedError("Canceled before a job was started")
+    def _no_job_launched(self) -> NoJobLaunchedError:
+        return NoJobLaunchedError("Canceled before a job was started")
 
     def get_batch_job(self) -> SlurmBatchJob:
-        return self._batch_job
+        return cast(SlurmBatchJob, self._batch_job)
 
 
 class WatchStage:
+    """
+    Watches a batch job until it completes
+    """
 
     class BatchJobProvider(Protocol):
 
@@ -75,7 +80,7 @@ class WatchStage:
     def __init__(self, batch_job_provider: BatchJobProvider, poll_interval: int) -> None:
         self._poll_interval = poll_interval
         self._provider = batch_job_provider
-        self._watcher: JobWatcher = None  # type: ignore[assignment]
+        self._watcher: Optional[JobWatcher] = None
         self._job_status: Optional[SlurmJobStatus] = None
 
     def __call__(self, ui: UI) -> bool:
@@ -95,11 +100,14 @@ class WatchStage:
         return callback
 
     def cancel(self, ui: UI) -> None:
-        self._watcher.stop()
+        get_or_raise(self._watcher, NotWatchingError).stop()
         self._provider.cancel(ui)
 
 
 class PrepareStage:
+    """
+    Copies the given files to the target filesystem.
+    """
 
     def __init__(self, filesystem_factory: FilesystemFactory, copy_instructions: List[CopyInstruction]) -> None:
         self._factory = filesystem_factory
@@ -143,6 +151,9 @@ class PrepareStage:
 
 
 class FinalizeStage:
+    """
+    Collects result files from the remote filesystem and cleans it according to the given instructions.
+    """
 
     def __init__(
             self, filesystem_factory: FilesystemFactory, collect_instructions: List[CopyInstruction],
@@ -180,6 +191,9 @@ class FinalizeStage:
 
 
 class StatusStage:
+    """
+    Checks a job's status.
+    """
 
     def __init__(self, controller: SlurmController, jobid: str) -> None:
         self._controller = controller
@@ -191,3 +205,20 @@ class StatusStage:
 
     def cancel(self, ui: UI) -> None:
         pass
+
+
+class CancelStage:
+    """
+    Cancels a running job
+    """
+
+    def __init__(self, controller: SlurmController, jobid: str):
+        self._controller = controller
+        self._jobid = jobid
+
+    def __call__(self, ui: UI) -> bool:
+        self._controller.cancel(self._jobid)
+        return True
+
+    def cancel(self, ui: UI) -> None:
+        pass
